package org.syncloud.webui;

import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.bio.SocketConnector;
import org.syncloud.facade.Service;
import syncloud.core.log.Logger;

public class WebServer implements Service {

    private static Logger logger = Logger.getLogger(WebServer.class);
    private Server server;
    private WebPortProvider portProvider;
    private final Connector connector;

    public WebServer(Server server, WebPortProvider portProvider) {
        this.server = server;
        this.portProvider = portProvider;
        connector = new SocketConnector();
        server.addConnector(connector);
    }

    public void start() {
        logger.info("starting");
        try {
            connector.setPort(portProvider.getPort());
            server.start();
            logger.info("started");
        } catch (Exception e) {
            logger.error("unable to start webui", e);
        }
    }

    public void stop() {
        if (server == null) {
            logger.info("not running");
            return;
        }
        logger.info("stopping");
        try {
            server.stop();
            logger.info("stopped");
        } catch (Exception e) {
            logger.error("unable to stop", e);
        }
    }

    public void join() throws InterruptedException {
        server.join();
    }

    public boolean isRunning() {
        return server.isRunning();
    }
}
