package org.syncloud.webui.servlet;

import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.net.URLCodec;
import org.json.JSONException;
import syncloud.core.log.Logger;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Map;

public abstract class JsonServlet extends HttpServlet {

    private static Logger logger = Logger.getLogger(JsonServlet.class);
    private URLCodec codec = new URLCodec();


    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        try {
            response.setContentType("text/html");
            response.setStatus(HttpServletResponse.SC_OK);

            String result = getResult(request.getParameterMap());

            response.getWriter().println(result);

        } catch (Exception e) {
            response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
            logger.error("unable to get result", e);
        }
    }

    public abstract String getResult(Map params) throws JSONException, ServletException;

    protected String getParameter(Map params, String name) {
        Object o = params.get(name);
        if (o == null)
            return null;
        String value = ((String[]) o)[0];
        try {
            value = codec.decode(value);
        } catch (DecoderException e) {
            logger.error("unable to url decode param: " + value, e);
        }
        return value;
    }
}
