package org.syncloud.webui.servlet;

import org.syncloud.facade.AuthenticationManager;
import syncloud.storage.StorageKey;
import syncloud.storage.User;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Map;

public abstract class SecuredJsonServlet extends JsonServlet {

    private AuthenticationManager manager;

    protected SecuredJsonServlet(AuthenticationManager manager) {

        this.manager = manager;
    }

    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        checkAuthentication(request);
        super.doGet(request, response);

    }

    private void checkAuthentication(HttpServletRequest request) {
        if (!manager.authenticated(getStorageKey(request.getParameterMap()))) {
            throw new RuntimeException();
        }
    }

    protected User getUser(Map params) {
        User user = User.ANONYMOUS;
        if (params.containsKey("login")) {
            String login = getParameter(params, "login");
            user = new User(login);
        }
        return user;
    }

    protected StorageKey getStorageKey(Map params) {
        User user = getUser(params);
        String storageId = getParameter(params, "storageId");
        return new StorageKey(storageId, user);
    }
}
